# Copyright 2004-2005 swissnex
# 
# This file is part of EventRegistration.
# 
# EventRegistration is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option) any
# later version.
# 
# EventRegistration is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
# 
# You should have received a copy of the GNU General Public License along with
# EventRegistration; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA  02111-1307  USA


from Products.Archetypes.public import BaseSchema
from Products.Archetypes.public import Schema
from Products.Archetypes.public import StringField
from Products.Archetypes.public import StringWidget 
from Products.Archetypes.public import SelectionWidget 
from Products.Archetypes.public import TextAreaWidget 
from Products.Archetypes.public import BaseContent
from Products.Archetypes.public import registerType
from Products.Archetypes.TemplateMixin import TemplateMixin
from Products.CMFCore import CMFCorePermissions
from DateTime import DateTime
from AccessControl import ClassSecurityInfo

from Products.EventRegistration.config import PROJECTNAME
from Products.EventRegistration.config import HONORIFICS

from Products.EventRegistration.utils import getDisplayList

# debugging needs
from Products.Archetypes.debug import log
from pprint import pformat


schema = BaseSchema.copy() + Schema((
	StringField('id',
		widget=StringWidget(
			visible = {
				'edit'  : 'hidden',
				'view'  : 'hidden',
				}
			),
		),
	StringField('title',
		widget=StringWidget(
			visible = {
				'edit'  : 'hidden',
				'view'  : 'hidden',
				}
			),
		accessor='Title',
		),
	StringField('honorific',
		required = True,
		searchable = False,
		vocabulary = 'HonorificsList',
		widget = SelectionWidget(
			label='Title',
			format = 'select',
			),
		),
	StringField(
		'first_name',
		required = True,
		searchable = False,
		widget = StringWidget(label = 'First Name'),
		),
	StringField(
		'last_name',
		required = True,
		searchable = False,
		widget = StringWidget(label = 'Last Name'),
		),
	StringField(
		'company',
		required = True,
		searchable = False,
		widget = StringWidget(label = 'Company'),
		),
	StringField(
		'job_title',
		required = True,
		searchable = False,
		widget = StringWidget(label = 'Job Title'),
		),
	StringField(
		'email',
		required = True,
		searchable = False,
		validator = 'isEmail',
		widget = StringWidget(label = 'Email Address'),
		),
	StringField(
		'phone',
		required = True,
		searchable = False,
		widget = StringWidget(label = 'Telephone Number'),
		),
	StringField(
		'street',
		required = False,
		searchable = False,
		widget = StringWidget(label = 'Street Address'),
		),
	StringField(
			'city',
			required = False,
			searchable = False, 
			widget = StringWidget(label = 'City'),
			),
	StringField(
			'state',
			required = False,
			searchable = False,
			widget = StringWidget(label = "State"),
			),
	StringField(
			'zip',
			required = False,
			searchable = False,
			widget = StringWidget(label = 'Zip Code'),
			),
	StringField(
			'website',
			required = False,
			searchable = False,
			widget = StringWidget(label = 'Website'),
			),
	StringField(
			'comments',
			required = False,
			searchable = False,
			widget = TextAreaWidget(label = 'Comments'),
			),
))


class Registrant(BaseContent):
	"""
	A person who has registered to participate in an Event
	"""

	schema = schema

	actions = (
			{
			'id'           : 'view',
			'name'         : 'View',
			'action'       : 'string:${object_url}/registrant_view',
			'permissions'  : (CMFCorePermissions.ModifyPortalContent, ),
			'category'     : 'object',
			},
			{
			'id'           : 'edit',
			'name'         : 'Edit',
			'action'       : 'string:${object_url}/base_edit',
			'permissions'  : (CMFCorePermissions.View, ),
			'category'     : 'object',
			},
			)

	def parentTitle(self):
		# no getattr, because if this doesn't work something is majorly hosed
		return self.REQUEST.PARENTS[1].title 

	def Title(self):
		'''automatically generates an appropriate title'''
		honorific = getattr(self, 'honorific', None)
		first = getattr(self, 'first_name', None)
		last = getattr(self, 'last_name', None)
		company = getattr(self, 'company', None)
		# The parent of a Registrant should always be an Event
		if honorific and first and last and company:
			title = '%s, %s %s (%s)' % (last, honorific, first, company)
		else:
			# the more informative title makes the pathbar too long (on a 17" screen), so display is uglified
			#title = 'Register for %s' % self.REQUEST.PARENTS[1].title
			title = 'Register'
		return title

	def HonorificsList(self):
		return getDisplayList(self, 'honorifics')

	def firstAndLast(self):
		first = getattr(self, 'first_name', None)
		last = getattr(self, 'last_name', None)
		return '%s %s' % (first, last)
	
	def bothCityAndState(self):
		'''returns true if both city and state are defined -- used to determine if the page template needs a comma'''
		city = getattr(self, 'city', None)
		state = getattr(self, 'state', None)
		if city and state:
			return True
		else:
			return False

def modify_fti(fti):
	'''\
	Disable global_allow so users cannot add a Registrant anywhere except inside an Event, where it is explicitly allowed.

	Disable references tab.

	Use custom view template.
	'''
	fti['global_allow'] = 0 
	for a in fti['actions']:
		if a['id'] in ('references', ):
			a['visible'] = False
		if a['id'] in ('view', ):
			a['action'] = 'string:${object_url}/registrant_view'
	return fti

registerType(Registrant, PROJECTNAME)
